(installation_link)=

# Installation

SHRY can be obtained from PyPI

```console
pip install shry
```

## Development

If you prefer to install from source, instead follow the procedures below.

```console
git clone https://github.com/shry-project/SHRY.git
cd shry
pip install -e .
```
